/**
 * @file GPIO_ledRGB.h
 * @brief Funcoes relacionadas com o controle do ledRGB via GPIO
 * @author Wu Shin TIng
 * @date 06/09/2020
 */

#ifndef GPIO_LEDRGB_H_
#define GPIO_LEDRGB_H_

/**
 * @brief Dois estados booleanos
 */
typedef enum estado_tag {
	DESABILITA,     /**< falso/apaga/desativa/liga */
	HABILITA,      /**< verdadeiro/acende/ativa/fecha */
} estado_type;

/**
 * @brief inicializa o componente ledRGB
 */
void GPIO_initLedRGB();

/**
 * @brief inicializa o led vermelho do ledRGB
 */
void GPIO_initLedR();

/**
 * @brief inicializa led verde do ledRGB
 */
void GPIO_initLedG();

/**
 * @brief inicializa led azul do led RGB
 */
void GPIO_initLedB();

/**
 * @brief seta o estado do led vermelho do componente ledRGB
 * @param[in] estado HABILITA/DESABILITA
 */
void GPIO_ledR(estado_type estado);

/**
 * @brief seta o estado do led verde do componente ledRGB
 * @param[in] estado HABILITA/DESABILITA
 */
void GPIO_ledG(estado_type estado);

/**
 * @brief seta o estado do led azul do componente ledRGB
 * @param[in] estado HABILITA/DESABILITA
 */
void GPIO_ledB(estado_type estado);

/**
 * @brief seta o estado do componente ledRGB
 * @param[in] estadoR HABILITA/DESABILITA led R
 * @param[in] estadoG HABILITA/DESABILITA led G
 * @param[in] estadoB HABILITA/DESABILITA led B
 */
void GPIO_ledRGB(estado_type estadoR, estado_type estadoG, estado_type estadoB);

#endif /* GPIO_LEDRGB_H_ */
